@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-
-master_doc = 'index'
 project = 'Sphinx'
 version = '1.4.4'
 
