@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-
-master_doc = 'index'
-
 extensions = ['sphinx.ext.imgmath']  # for math_numfig
 
 latex_documents = [
