@@ -1,8 +1,5 @@
-# -*- coding: utf-8 -*-
-
 import os
 import sys
 
 sys.path.insert(0, os.path.abspath('sample-0.0.0-py3.7.egg'))
-master_doc = 'index'
 extensions = ['sphinx.ext.autodoc']
