@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-
-master_doc = 'index'
 html_theme = 'classic'
 templates_path = ['_templates']
 
